@@ -14,8 +14,9 @@
 #' @export
 unique_osmdata <- function (dat) {
 
-    if (!is (dat, "osmdata"))
+    if (!is (dat, "osmdata")) {
         stop ("dat must be an osmdata object")
+    }
 
     if (is (dat$osm_points, "sf")) {
 
@@ -43,13 +44,15 @@ unique_points_sf <- function (dat) {
 
     pts <- paste0 (dat$osm_points$osm_id)
 
-    lns_pts <- unlist (lapply (dat$osm_lines$geometry, function (i)
-                               rownames (i)))
+    lns_pts <- unlist (lapply (dat$osm_lines$geometry, function (i) {
+        rownames (i)
+    }))
     names (lns_pts) <- NULL
     lns_pts <- unique (lns_pts)
 
-    poly_pts <- unlist (lapply (dat$osm_polygons$geometry, function (i)
-                                rownames (i [[1]])))
+    poly_pts <- unlist (lapply (dat$osm_polygons$geometry, function (i) {
+        rownames (i [[1]])
+    }))
     names (poly_pts) <- NULL
     poly_pts <- unique (poly_pts)
 
@@ -64,15 +67,17 @@ unique_points_sp <- function (dat) {
     pts <- rownames (slot (dat$osm_points, "data"))
 
     lns <- slot (dat$osm_lines, "lines")
-    lns_pts <- lapply (lns, function (i)
-                       rownames (slot (slot (i, "Lines") [[1]], "coords")))
+    lns_pts <- lapply (lns, function (i) {
+        rownames (slot (slot (i, "Lines") [[1]], "coords"))
+    })
     lns_pts <- unlist (lns_pts)
     names (lns_pts) <- NULL
     lns_pts <- unique (lns_pts)
 
     polys <- slot (dat$osm_polygons, "polygons")
-    poly_pts <- lapply (polys, function (i)
-                        rownames (slot (slot (i, "Polygons") [[1]], "coords")))
+    poly_pts <- lapply (polys, function (i) {
+        rownames (slot (slot (i, "Polygons") [[1]], "coords"))
+    })
     poly_pts <- unlist (poly_pts)
     names (poly_pts) <- NULL
     poly_pts <- unique (poly_pts)
@@ -115,8 +120,9 @@ unique_polygons_sf <- function (dat) {
 
     polys <- paste0 (dat$osm_polygons$osm_id)
 
-    mpolys <- unlist (lapply (dat$osm_multipolygons$geometry, function (i)
-                              names (i [[1]])))
+    mpolys <- unlist (lapply (dat$osm_multipolygons$geometry, function (i) {
+        names (i [[1]])
+    }))
     names (mpolys) <- NULL
     mpolys <- unique (mpolys)
 
@@ -131,8 +137,9 @@ unique_polygons_sp <- function (dat) {
     polys <- rownames (slot (dat$osm_polygons, "data"))
 
     mpolys <- slot (dat$osm_multipolygons, "polygons")
-    mpolys <- unlist (lapply (mpolys, function (i)
-                              names (slot (i, "Polygons"))))
+    mpolys <- unlist (lapply (mpolys, function (i) {
+        names (slot (i, "Polygons"))
+    }))
     names (mpolys) <- NULL
     mpolys <- unique (mpolys)
 
