@@ -100,17 +100,17 @@ struct UniqueVals
 struct RawNode
 {
     osmid_t id;
-    std::string _version, _timestamp, _changeset, _uid, _user; // metadata
+    std::string _version = "", _timestamp = "", _changeset = "", _uid = "", _user = ""; // metadata
     std::vector <std::string> key, value;
-    double lat, lon;
+    double lat = DOUBLE_MAX, lon = DOUBLE_MAX;
 };
 
 struct Node
 {
     osmid_t id;
-    std::string _version, _timestamp, _changeset, _uid, _user; // metadata
+    std::string _version = "", _timestamp = "", _changeset = "", _uid = "", _user = ""; // metadata
     std::map <std::string, std::string> key_val;
-    double lat, lon;
+    double lat = DOUBLE_MAX, lon = DOUBLE_MAX;
 };
 
 /* Traversing the XML tree means keys and values are read sequentially and
